==> dl.php?src=linea21_1_8.zip: linea21/tag/help.php <==
<?php
/**
 * Tag module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\core\tag
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>
<div id="aide">

<?php
if ($todo == 'det') {
?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('tag','det');?></p>
<ul>
	<li><?php echo _t('tag','help_add1');?></li>
	<li><?php echo _t('tag','help_det1');?></li>
</ul>

  <?php }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('tag','mod');?></p>
<ul>
	<li><?php echo _t('tag','help_add1');?></li>
	<li><?php echo _t('tag','help_mod1');?></li>
	<li><?php echo _t('tag','help_mod2');?></li>
	<li><?php echo _t('tag','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'list') {
      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('tag','list');?></p>
<ul>
	<li><?php echo _t('tag','help_add1');?></li>
	<li><?php echo _t('tag','help_list1');?></li>
	<li><?php echo _t('tag','help_list2');?></li>
	<li><?php echo _t('tag','help_list3');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->

==> dl.php?src=linea21_2_8_0.zip: linea21/tag/help.php <==
<?php
/**
 * Tag module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\core\tag
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="fa fa-life-ring" aria-hidden="true"></i> <?php echo _t('help','title');?></a>
<div id="aide">

<?php
if ($todo == 'det') {
?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('tag','det');?></p>
<ul>
	<li><?php echo _t('tag','help_add1');?></li>
	<li><?php echo _t('tag','help_det1');?></li>
</ul>

  <?php }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('tag','mod');?></p>
<ul>
	<li><?php echo _t('tag','help_add1');?></li>
	<li><?php echo _t('tag','help_mod1');?></li>
	<li><?php echo _t('tag','help_mod2');?></li>
	<li><?php echo _t('tag','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'list') {
      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('tag','list');?></p>
<ul>
	<li><?php echo _t('tag','help_add1');?></li>
	<li><?php echo _t('tag','help_list1');?></li>
	<li><?php echo _t('tag','help_list2');?></li>
	<li><?php echo _t('tag','help_list3');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->
